Ag nanoparticle | Nature Search Results

Skip to main content

Thank you for visiting nature.com. You are using a browser version with limited support for CSS. To obtain the best experience, we recommend you use a more up to date browser (or turn off compatibility mode in Internet Explorer). In the meantime, to ensure continued support, we are displaying the site without styles and JavaScript.

Advertisement

# Search

Advanced search

## Filter By:

Journal
Check one or more journals to show results from those journals only.

- Scientific Reports (1219)
- Nature Communications (448)
- Nature Nanotechnology (96)
- Nature Materials (84)
- NPG Asia Materials (55)

Choose more journals

Article type
Check one or more article types to show results from those article types only.

- Research (2136)
- Reviews (255)
- Protocols (28)
- News & Views (15)
- Research Highlights (13)
- Comments & Opinion (7)
- Special Features (5)
- Amendments and Corrections (4)
- News (3)
- Advertorial (1)
- Correspondence (1)
- Multimedia (1)

Subject
Check one or more subjects to show results from those subjects only.

- Biochemistry
- Biological techniques
- Biophysics
- Biotechnology
- Cancer
- Cell biology
- Chemical biology
- Chemistry
- Diseases
- Energy science and technology
- Engineering
- Environmental sciences
- Health care
- Immunology
- Materials science
- Medical research
- Microbiology
- Nanoscience and technology
- Optics and photonics
- Physics

Date
Choose a date option to show results from those dates only.

- Today
- Last 7 days
- Last 30 days
- Last 12 months
- Last 2 years
- Last 5 years

Custom date range

Clear all filters
Showing 1–50 of 2469 results
Sort by Relevance

- ### Stress-induced phase transformation and optical coupling of silver nanoparticle superlattices into mechanically stable nanowires

  Silver nanowires are commonly synthesized via chemical routes. Here, the authors report nanowire formation via a physical method involving stress-induced phase transformation and sintering of spherical silver nanoparticle superlattices.

  - Binsong Li
  - Xiaodong Wen
  - Hongyou Fan
  Research 24 Jun 2014
  Nature Communications
  Volume: 5, P: 1-7

- ### Shuttling single metal atom into and out of a metal nanoparticle

  Doping a metal nanocluster with heteroatoms dramatically changes its properties, but it remains difficult to dope with single-atom control. Here, the authors devise a strategy to dope single atoms of Ag or Cu into hollow Au nanoclusters, creating precise alloy nanoparticles atom-by-atom.

  - Shuxin Wang
  - Hadi Abroshan
  - Rongchao Jin
  Research Open Access 10 Oct 2017
  Nature Communications
  Volume: 8, P: 1-7

- ### Dynamic protein coronas revealed as a modulator of silver nanoparticle sulphidation in vitro

  The biomolecule layer adsorbed at the nanoparticle surface and defined as protein corona affects the nanoparticle biophysical properties and functions. Here, the authors suggest that rapidly-exchanging proteins on the outermost layer of the corona modulate sulphidation of silver nanoparticles in vitro.

  - Teodora Miclăuş
  - Christiane Beer
  - Duncan S. Sutherland
  Research Open Access 09 Jun 2016
  Nature Communications
  Volume: 7, P: 1-10

- ### Au–Ag alloy nanoparticle-incorporated AgBr plasmonic photocatalyst

  - Shin-ichi Naya
  - Hiroaki Tada
  Research Open Access 17 Nov 2020
  Scientific Reports
  Volume: 10, P: 1-7

- ### Selective CO2 electrocatalysis at the pseudocapacitive nanoparticle/ordered-ligand interlayer

  The complex, multi-component environments found in enzymes induce high catalytic specificity, but are difficult to achieve in synthetic catalysts. Now, researchers report a catalyst comprising a dynamic, ordered layer of ligands above a nanoparticle surface that creates a pocket to facilitate CO2 electroreduction.

  - Dohyung Kim
  - Sunmoon Yu
  - Peidong Yang
  Research 30 Nov 2020
  Nature Energy
  Volume: 5, P: 1032-1042

- ### An environmentally benign antimicrobial nanoparticle based on a silver-infused lignin core

  Biodegradable lignin nanoparticles infused with minimal amounts of silver ions and coated with a cationic polyelectrolyte show short-term broad-spectrum antimicrobial activity, offering an environmentally friendly alternative to metallic silver nanoparticles.

  - Alexander P. Richter
  - Joseph S. Brown
  - Orlin D. Velev
  Research 13 Jul 2015
  Nature Nanotechnology
  Volume: 10, P: 817-823

- ### Breaking the barrier to biomolecule limit-of-detection via 3D printed multi-length-scale graphene-coated electrodes

  Here, the authors introduce a biosensing platform with multi-length-scale electrode architecture consisting of 3D printed silver micropillars decorated with graphene flakes. They demonstrate that this breaks a barrier to the biomolecule limit-of-detection, enabling detection down to femtomolar level.

  - Md. Azahar Ali
  - Chunshan Hu
  - Rahul Panat
  Research Open Access 06 Dec 2021
  Nature Communications
  Volume: 12, P: 1-16

- ### Etchable plasmonic nanoparticle probes to image and quantify cellular internalization

  Nanoparticle-based fluorescence imaging does not usually allow cell membrane-bound particles and intracellular particles to be distinguished from each other. Now, using functionalized silver nanoparticles as plasmonic probes, this distinction can be made following a rapid, non-toxic etching process that selectively removes the extracellular nanoparticles but leaves the intracellular nanoparticles unharmed.

  - Gary B. Braun
  - Tomas Friman
  - Erkki Ruoslahti
  Research 08 Jun 2014
  Nature Materials
  Volume: 13, P: 904-911

- ### Effect of Ag nanoparticle concentration on the electrical and ferroelectric properties of Ag/P(VDF-TrFE) composite films

  - Haemin Paik
  - Yoon-Young Choi
  - Kwangsoo No
  Research Open Access 04 Sept 2015
  Scientific Reports
  Volume: 5, P: 1-7

- ### Silver-nanoparticle-embedded antimicrobial paints based on vegetable oil

  - Ashavani Kumar
  - Praveen Kumar Vemula
  - George John
  Research 20 Jan 2008
  Nature Materials
  Volume: 7, P: 236-241

- ### Atomic scale observation of oxygen delivery during silver–oxygen nanoparticle catalysed oxidation of carbon nanotubes

  Probing the dynamics of atomic scale catalytic processes leads to improved mechanistic understanding and catalyst design. Here, the authors use environmental electron microscopy and first-principles calculations to semi-quantitatively analyse silver nanoparticle catalysed carbon nanotube oxidation.

  - Yonghai Yue
  - Datong Yuchi
  - Jingyue Liu
  Research Open Access 13 Jul 2016
  Nature Communications
  Volume: 7, P: 1-7

- ### Enzyme-catalyzed Ag Growth on Au Nanoparticle-assembled Structure for Highly Sensitive Colorimetric Immunoassay

  - Xuan-Hung Pham
  - Eunil Hahm
  - Bong-Hyun Jun
  Research Open Access 19 Apr 2018
  Scientific Reports
  Volume: 8, P: 1-7

- ### Active and stable carbon nanotube/nanoparticle composite electrocatalyst for oxygen reduction

  Cheap, efficient oxygen reduction reaction catalysts are vital for the development of fuel cells and lithium-air batteries. Here, the authors report the scalable synthesis of a nitrogen-doped carbon nanotube/nanoparticle hybrid material that outperforms several platinum-based catalysts.

  - Hoon T. Chung
  - Jong H. Won
  - Piotr Zelenay
  Research Open Access 28 May 2013
  Nature Communications
  Volume: 4, P: 1-5

- ### Potential energy surfaces and reaction pathways for light-mediated self-organization of metal nanoparticle clusters

  Understanding the interactions between nanoparticles is vital for controlling their assembly. Here, the authors show how photonic control and binding of nanoparticles can be understood with the concept of potential energy surfaces, giving path-dependent formation of clusters.

  - Zijie Yan
  - Stephen K. Gray
  - Norbert F. Scherer
  Research 02 May 2014
  Nature Communications
  Volume: 5, P: 1-7

- ### Enhanced DSSCs efficiency via Cooperate co-absorbance (CdS QDs) and plasmonic core-shell nanoparticle (Ag@PVP)

  - Omid Amiri
  - Masoud Salavati-Niasari
  - Amin Termeh Yousefi
  Research Open Access 04 May 2016
  Scientific Reports
  Volume: 6, P: 1-10

- ### Mapping surface plasmons on a single metallic nanoparticle

  - Jaysen Nelayah
  - Mathieu Kociak
  - Christian Colliex
  Research 01 Apr 2007
  Nature Physics
  Volume: 3, P: 348-353

- ### Dynamic hook-and-eye nanoparticle sponges

  An organic polymer scaffold has now been developed that can capture and release functionalized inorganic nanoparticles by the threading and de-threading of pseudorotaxane linkages. The capture–release cycles are reversible and programmable both chemically and electrochemically. In mixtures of different nanoparticles, the scaffold can capture one type selectively — thus acting as a selective nanoparticle ‘sponge’.

  - Rafal Klajn
  - Mark A. Olson
  - Bartosz A. Grzybowski
  Research 15 Nov 2009
  Nature Chemistry
  Volume: 1, P: 733-738

- ### Enhanced photocatalysis and biomolecular sensing with field-activated nanotube-nanoparticle templates

  Plasmonic nanomaterials offer new frontiers as photocatalysis and sensor materials, yet elucidating factors controlling each is a challenge. Here, authors examine the role of electric fields in photocatalysis and biomolecule sensing abilities of peptide-nanotubesupported silver nanoparticles.

  - Sawsan Almohammed
  - Sebastian Tade Barwich
  - James H. Rice
  Research Open Access 07 Jun 2019
  Nature Communications
  Volume: 10, P: 1-11

- ### Synthesis of silver nanostructure on gold nanoparticle using near field assisted second harmonic generation

  - Takashi Yatsui
  - Felix Brandenburg
  - Olivier Soppera
  Research Open Access 11 Mar 2021
  Scientific Reports
  Volume: 11, P: 1-8

- ### Iron and sulfide nanoparticle formation and transport in nascent hydrothermal vent plumes

  There has been much interest recently in the transport mechanisms of metals from hydrothermal vents. Here the authors found that nanoparticulate pyrite is not removed from the plume and can account for over 50% of filtered iron one metre from the vent mouth.

  - Alyssa J. Findlay
  - Emily R. Estes
  - George W. Luther III
  Research Open Access 08 Apr 2019
  Nature Communications
  Volume: 10, P: 1-7

- ### Catechol-Functional Chitosan/Silver Nanoparticle Composite as a Highly Effective Antibacterial Agent with Species-Specific Mechanisms

  - Xiaofei Huang
  - Xiaojiong Bao
  - Qiaoling Hu
  Research Open Access 12 May 2017
  Scientific Reports
  Volume: 7, P: 1-10

- ### Nanoparticle fouling and its combination with organic fouling during forward osmosis process for silver nanoparticles removal from simulated wastewater

  - Yanxiao Zhao
  - Xinhua Wang
  - Yueping Ren
  Research Open Access 10 May 2016
  Scientific Reports
  Volume: 6, P: 1-10

- ### Hybrid silver nanoparticle/conjugated polyelectrolyte nanocomposites exhibiting controllable metal-enhanced fluorescence

  - Xiaoyu Wang
  - Fang He
  - Lidong Li
  Research Open Access 18 Mar 2014
  Scientific Reports
  Volume: 4, P: 1-6

- ### Recycling silver nanoparticle debris from laser ablation of silver nanowire in liquid media toward minimum material waste

  - June Sik Hwang
  - Jong-Eun Park
  - Minyang Yang
  Research Open Access 26 Jan 2021
  Scientific Reports
  Volume: 11, P: 1-11

- ### Plasmonic Nanoparticle-based Hybrid Photosensitizers with Broadened Excitation Profile for Photodynamic Therapy of Cancer Cells

  - Peng Wang
  - Hong Tang
  - Peng Zhang
  Research Open Access 11 Oct 2016
  Scientific Reports
  Volume: 6, P: 1-8

- ### Nanoparticle behaviour dissected

  Measuring changes in the isotopic composition of silver offers clues on how silver nanoparticles are transformed in the environment.

  - Frank Vanhaecke
  News & Views 20 Jun 2016
  Nature Nanotechnology
  Volume: 11, P: 656-657

- ### Imparting functionality to a metal–organic framework material by controlled nanoparticle encapsulation

  Surfactant-capped nanoparticles of various sizes, shapes and compositions have been completely enshrouded within a metal–organic framework in a controlled, well-dispersed manner. The resulting hybrid materials exhibit active properties — catalytic, magnetic and optical — arising from the nanoparticles as well as sieving and orientation effects originating from the porous framework.

  - Guang Lu
  - Shaozhou Li
  - Fengwei Huo
  Research 19 Feb 2012
  Nature Chemistry
  Volume: 4, P: 310-316

- ### Nanoparticle printing with single-particle resolution

  - Tobias Kraus
  - Laurent Malaquin
  - Heiko Wolf
  Research 02 Sept 2007
  Nature Nanotechnology
  Volume: 2, P: 570-576

- ### Sinter-resistant metal nanoparticle catalysts achieved by immobilization within zeolite crystals via seed-directed growth

  Supported metal nanoparticles are indispensable catalysts in industry, yet they are often subjected to severe sintering. Now, a general method based on metal immobilization within zeolite is reported for the preparation of highly sinter-resistant catalysts for a broad range of industrially relevant processes.

  - Jian Zhang
  - Liang Wang
  - Feng-Shou Xiao
  Research 09 Jul 2018
  Nature Catalysis
  Volume: 1, P: 540-546

- ### Two distinctive energy migration pathways of monolayer molecules on metal nanoparticle surfaces

  Energy migrations at metal nanomaterial surfaces are fundamentally important to heterogeneous reactions. Here, the authors employ ultrafast vibrational spectroscopy to show two distinctive energy migration pathways of monolayer adsorbate molecules on differently sized metal nanoparticle surfaces.

  - Jiebo Li
  - Huifeng Qian
  - Junrong Zheng
  Research Open Access 17 Feb 2016
  Nature Communications
  Volume: 7, P: 1-8

- ### Nanoparticle chemisorption printing technique for conductive silver patterning with submicron resolution

  Silver nanocolloids are promising materials for printed electronic technologies. Here, the authors manufacture ultrafine conductive patterns utilizing the exclusive chemisorption of weakly encapsulated silver nanocolloids on a photoactivated surface.

  - Toshikazu Yamada
  - Katsuo Fukuhara
  - Tatsuo Hasegawa
  Research Open Access 19 Apr 2016
  Nature Communications
  Volume: 7, P: 1-9

- ### Nonlinearity-induced nanoparticle circumgyration at sub-diffraction scale

  It has been challenging to rotate nanoparticles orbitally via optical trapping beyond the diffraction limit. Here, the authors take advantage of the nonlinear optical effect and demonstrate fast and controlled orbital rotation at subwavelength scale with a femtosecond pulsed Gaussian beam.

  - Yaqiang Qin
  - Lei-Ming Zhou
  - Yuqiang Jiang
  Research Open Access 17 Jun 2021
  Nature Communications
  Volume: 12, P: 1-8

- ### Nanoscale form dictates mesoscale function in plasmonic DNA–nanoparticle superlattices

  Two- and three-dimensional mesoscale superlattice crystals with precisely engineered optical properties can be assembled from the bottom up by using DNA as a programmable ligand.

  - Michael B. Ross
  - Jessie C. Ku
  - Chad A. Mirkin
  Research 13 Apr 2015
  Nature Nanotechnology
  Volume: 10, P: 453-458

- ### Co-detection: Ultra-reliable Nanoparticle-Based Electrical Detection of Biomolecules in the Presence of Large Background Interference

  - Yang Liu
  - Evangelyn Alocilja
  - Shantanu Chakrabartty
  Research Open Access 27 Apr 2010
  Nature Precedings
  P: 1

- ### Magnetic Resonance imaging (MRI) in detection of Bifidobacterium longum and Clostridium novyi-NT labeled with superparamagnetic iron oxide (SPIO) nanoparticle

  - Jianhua Wang
  - Xuebin Zhang
  - Dan Li
  Research Open Access 22 Jul 2009
  Nature Precedings
  P: 1

- ### Control on Surface Plasmon Polaritons Propagation Properties by Continuously Moving a Nanoparticle along a Silver Nanowire Waveguide

  - Fan Wu
  - Wenhui Wang
  - Fuli Li
  Research Open Access 22 Nov 2016
  Scientific Reports
  Volume: 6, P: 1-7

- ### Dual Electrophoresis Detection System for Rapid and Sensitive Immunoassays with Nanoparticle Signal Amplification

  - Fangfang Zhang
  - Junjie Ma
  - Heyun Shen
  Research Open Access 15 Feb 2017
  Scientific Reports
  Volume: 7, P: 1-9

- ### Mass spectrometry and Monte Carlo method mapping of nanoparticle ligand shell morphology

  Determining the arrangement of ligands on a nanoparticle is challenging, given the limitations of existing characterization tools. Here, the authors describe an accessible method for resolving ligand shell morphology that uses simple MALDI-TOF mass spectrometry measurements in conjunction with an open-access Monte Carlo fitting program.

  - Zhi Luo
  - Yanfei Zhao
  - Francesco Stellacci
  Research Open Access 26 Oct 2018
  Nature Communications
  Volume: 9, P: 1-9

- ### Synergistic Antibacterial Effects of Metallic Nanoparticle Combinations

  - C. Bankier
  - R. K. Matharu
  - L. Ciric
  Research Open Access 05 Nov 2019
  Scientific Reports
  Volume: 9, P: 1-8

- ### Controlling anisotropic nanoparticle growth through plasmon excitation

  - Rongchao Jin
  - Y. Charles Cao
  - Chad A. Mirkin
  Research 02 Oct 2003
  Nature
  Volume: 425, P: 487-490

- ### Scalable Synthesis of Ag Networks with Optimized Sub-monolayer Au-Pd Nanoparticle Covering for Highly Enhanced SERS Detection and Catalysis

  - Tianyu Li
  - Sascha Vongehr
  - Xiangkang Meng
  Research Open Access 15 Nov 2016
  Scientific Reports
  Volume: 6, P: 1-11

- ### Strategic design of a Mussel-inspired in situ reduced Ag/Au-Nanoparticle Coated Magnesium Alloy for enhanced viability, antibacterial property and decelerated corrosion rates for degradable implant Applications

  - Abdelrahman I. Rezk
  - Arathyram Ramachandra Kurup Sasikala
  - Cheol Sang Kim
  Research Open Access 15 Jan 2019
  Scientific Reports
  Volume: 9, P: 1-12

- ### Enhanced wound healing properties of guar gum/curcumin-stabilized silver nanoparticle hydrogels

  - Sakkarin Bhubhanil
  - Chanon Talodthaisong
  - Sirinan Kulchat
  Research Open Access 08 Nov 2021
  Scientific Reports
  Volume: 11, P: 1-14

- ### Hydrogen-bonded structure and mechanical chiral response of a silver nanoparticle superlattice

  Self-assembled nanoparticle superlattices, which consist of inorganic cores capped by organic ligands, can show emergent behaviour as a result of the coupling between their nanoscale components. The atom-level structure of a silver nanoparticle superlattice, deduced from X-ray imaging and simulations, is now reported as well as its response to hydrostatic compression, which involves anomalous pressure softening and correlated chiral rotation of the nanoparticles.

  - Bokwon Yoon
  - W. D. Luedtke
  - Uzi Landman
  Research 06 Apr 2014
  Nature Materials
  Volume: 13, P: 807-811

- ### Antibacterial property of Ag nanoparticle-impregnated N-doped titania films under visible light

  - Ming-Show Wong
  - Chun-Wei Chen
  - Hsin-Hou Chang
  Research Open Access 09 Jul 2015
  Scientific Reports
  Volume: 5, P: 1-11

- ### Uncovering loss mechanisms in silver nanoparticle-blended plasmonic organic solar cells

  Metallic nanoparticles are commonly used to facilitate light trapping in organic solar cells, but they can also reduce cell performance. Wu et al.demonstrate that a trap-assisted recombination of charge carriers leads to degradation, irrespective of an initially enhanced absorption and excitation.

  - Bo Wu
  - Xiangyang Wu
  - Tze Chien Sum
  Research 13 Jun 2013
  Nature Communications
  Volume: 4, P: 1-7

- ### Microengineered human blood–brain barrier platform for understanding nanoparticle transport mechanisms

  Developing an in vitro blood-brain-barrier (BBB) model that reproduces the organ’s complex structure and function is an open challenge. Here the authors present a BBB-on-a-chip that includes endothelial cells, pericytes and a 3D astrocytic network which resembles the morphology and function of astrocytes in the BBB in vivo.

  - Song Ih Ahn
  - Yoshitaka J. Sei
  - YongTae Kim
  Research Open Access 10 Jan 2020
  Nature Communications
  Volume: 11, P: 1-12

- ### Sn(IV)-free tin perovskite films realized by in situ Sn(0) nanoparticle treatment of the precursor solution

  Tin based perovskites are easily oxidized, which generates large density of defects and compromised the solar cell efficiency. Here Nakamura et al. add metallic tin nanoparticles in the precursor solution to suppress tin (IV) impurities and enable high efficiency tin based perovskite solar cells.

  - Tomoya Nakamura
  - Shinya Yakumaru
  - Atsushi Wakamiya
  Research Open Access 16 Jun 2020
  Nature Communications
  Volume: 11, P: 1-8

- ### Structural diversity in binary nanoparticle superlattices

  - Elena V. Shevchenko
  - Dmitri V. Talapin
  - Christopher B. Murray
  Research 05 Jan 2006
  Nature
  Volume: 439, P: 55-59

- ### Local detection of electromagnetic energy transport below the diffraction limit in metal nanoparticle plasmon waveguides

  - Stefan A. Maier
  - Pieter G. Kik
  - Ari A.G. Requicha
  Research 02 Mar 2003
  Nature Materials
  Volume: 2, P: 229-232